@@ -4,8 +4,8 @@
 #include <glib-object.h>
 #include "fr-enum-types.h"
 
-/* enumerations from "/usr/src/ports/file-roller/file-roller-3.16.4-1.x86_64/src/file-roller-3.16.4/src/typedefs.h" */
-#include "/usr/src/ports/file-roller/file-roller-3.16.4-1.x86_64/src/file-roller-3.16.4/src/typedefs.h"
+/* enumerations from "/usr/src/ports/file-roller/file-roller-3.22.3-1.i686/src/file-roller-3.22.3/src/typedefs.h" */
+#include "/usr/src/ports/file-roller/file-roller-3.22.3-1.i686/src/file-roller-3.22.3/src/typedefs.h"
 GType
 fr_clipboard_op_get_type (void)
 {
